@@ -92,6 +92,7 @@ class DBConnect:
             return False
 
     def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
+        # 标准更新
         try:
             # 将参数id处理成符合mongo格式的_id对象
             find_docu = handle_db_id(find_docu)
@@ -118,6 +119,7 @@ class DBConnect:
             )
 
     def update_docu_inc(self, find_docu: dict, modify_docu: dict, many=False) -> dict:
+        # 字段自增更新
         try:
             # 将参数id处理成符合mongo格式的_id对象
             find_docu = handle_db_id(find_docu)
@@ -193,6 +195,20 @@ class DBConnect:
                 other={'prompt': str(err)}
             )
 
+    def find_docu_distinct(self, find_str: str) -> int:
+        # 去重查询
+        try:
+            query_res = self.mongo_collection.distinct(find_str)
+            if query_res:
+                return int(query_res[0])
+            return 0
+        except Exception as err:
+            handle_abnormal(
+                message='MongoDB(组件)出现查询错误',
+                status=500,
+                other={'prompt': str(err)}
+            )
+
     def find_docu_by_id(self, id: str, raise_err=True) -> dict:
         """
         根据id查找记录
